@@ -13,6 +13,6 @@ class AzureStorageKeyDetector(RegexBasedDetector):
     denylist = [
         # Account Key (AccountKey=xxxxxxxxx)
         re.compile(
-            r'AccountKey=[a-zA-Z0-9+\/=]{88}',
+            r'(?:[A-Za-z0-9+\/]{86,20000}==)$',
         ),
     ]
